@@ -50,6 +50,10 @@ impl NumberInstance for Boolean {
         Float::cast_from(self).exp()
     }
 
+    fn ln(self) -> Self::Log {
+        Float::cast_from(self).ln()
+    }
+
     fn log<N: NumberInstance>(self, base: N) -> Self::Log
     where
         Float: From<N>,
@@ -302,6 +306,13 @@ impl NumberInstance for Complex {
         }
     }
 
+    fn ln(self) -> Self::Log {
+        match self {
+            Self::C32(c) => c.ln().into(),
+            Self::C64(c) => c.ln().into(),
+        }
+    }
+
     fn log<N: NumberInstance>(self, base: N) -> Self::Log
     where
         Float: From<N>,
@@ -753,6 +764,13 @@ impl NumberInstance for Float {
         }
     }
 
+    fn ln(self) -> Self::Log {
+        match self {
+            Self::F32(f) => f.ln().into(),
+            Self::F64(f) => f.ln().into(),
+        }
+    }
+
     fn log<N: NumberInstance>(self, base: N) -> Self::Log
     where
         Float: From<N>,
@@ -1197,6 +1215,10 @@ impl NumberInstance for Int {
         Float::from(self).exp()
     }
 
+    fn ln(self) -> Self::Log {
+        Float::from(self).ln()
+    }
+
     fn log<N: NumberInstance>(self, base: N) -> Self::Log
     where
         Float: From<N>,
@@ -1668,6 +1690,10 @@ impl NumberInstance for UInt {
         Float::from(self).exp()
     }
 
+    fn ln(self) -> Self::Log {
+        Float::from(self).ln()
+    }
+
     fn log<N: NumberInstance>(self, base: N) -> Self::Log
     where
         Float: From<N>,
